@@ -1,4 +1,4 @@
-from .constants import PANDAS_TYPES, PYSPARK_TYPES, KOALAS_TYPES, PANDAS_ON_SPARK_TYPES, PANDAS, KOALAS, SPARK, PANDAS_ON_SPARK, IN_PANDAS_ON_SPARK
+from .constants import PANDAS_TYPES, PYSPARK_TYPES, KOALAS_TYPES, PANDAS_ON_SPARK_TYPES, PANDAS, KOALAS, SPARK, PYSPARK, PANDAS_ON_SPARK, IN_PANDAS_ON_SPARK
 
 from typing import List
 from tqdm import tqdm
@@ -198,10 +198,10 @@ def to_list(df, columns: List[str] = None):
 
 def df_type(df):
     if str(type(df)) == "<class 'pandas.core.frame.DataFrame'>":
-        return "pandas"
+        return PANDAS
     elif str(type(df)) == "<class 'pyspark.sql.dataframe.DataFrame'>":
-        return "spark"
+        return PYSPARK
     elif str(type(df)) == "<class 'databricks.koalas.frame.DataFrame'>":
-        return "koalas"
+        return KOALAS
     elif str(type(df)) == "<class 'pyspark.pandas.frame.DataFrame'>":
-        return "ps"
\ No newline at end of file
+        return PANDAS_ON_SPARK
\ No newline at end of file
